#!/usr/bin/env python3
# -*- coding: utf-8 -*-


from PyQt5 import QtWidgets
from collections import OrderedDict
from numpy import arange

from eccw_gui.shared.viewers.lineEdit import Ui_Form
from eccw_gui.shared.viewers.lineEdit_bound import Ui_Form as Ui_Form_bound
from eccw_gui.shared.viewers.lineEdit_range import Ui_Form as Ui_Form_range
from eccw_gui.shared.viewers.lineEdit_switch import Ui_Form as Ui_Form_switch
from eccw_gui.shared.tools import float_check, str_check, graph_print
from eccw_gui.shared.wrappers import Wrapper, WrapperDict


class LineEdit(QtWidgets.QWidget, Ui_Form):
    """Line edit widget.

    Arguments:
    Awaits a single argument.
    Any entry will initiate the line edit with a string interpretation
    of the argument.
    This is a Qt derived object.
    """

    def __init__(self, *args):
        super(LineEdit, self).__init__()
        self.id = ""
        self.setupUi(self)
        # Fill values with args
        if args:
            self.set_params(*args)
        self.show()

    def get_params(self):
        return self.lineEdit.text()

    def set_params(self, arg):
        self.lineEdit.setText(str_check(arg))

    def get_select(self):
        return self.get_params()

    def clear(self):
        self.lineEdit.clear()


class StringLineEdit(LineEdit):
    """Line edit widget for string entry.

    Arguments:
    Awaits a single string argument.
    Any entry will initiate the line edit with a string interpretation
    of the argument.
    This is a Qt derived object.
    """

    def __init__(self, *args):
        LineEdit.__init__(self, *args)
        self.id = "string"


class ScalarLineEdit(LineEdit):
    """Line edit widget for scalar number entry.

    Arguments:
    Awaits a single number argument.
    Any entry will initiate the line edit with a string interpretation
    of the argument.
    This is a Qt derived object.
    """

    def __init__(self, *args):
        LineEdit.__init__(self, *args)
        self.id = "scalar"

    def get_params(self):
        return float_check(self.lineEdit.text())


class BoundLineEdit(QtWidgets.QWidget, Ui_Form_bound, WrapperDict):
    """Line edit widget for number bounds entry.

    Keyword arguments:
    min -- minimal bounding value
    max -- maximal bounding value

    Any entry will initiate the line edit with a string interpretation
    of the arguments.
    This is a Qt derived object.
    """

    def __init__(self, **kwargs):
        super(BoundLineEdit, self).__init__()
        self.id = "bound"
        self.setupUi(self)
        self.min = Wrapper(
            action=lambda x: self.lineEdit_min.setText(str_check(x)),
            process=lambda x: None if x == "-inf" else x,
        )
        self.min.get_params = lambda: float_check(
            self.lineEdit_min.text(), default=-float("inf")
        )
        self.max = Wrapper(
            action=lambda x: self.lineEdit_max.setText(str_check(x)),
            process=lambda x: None if x == "inf" else x,
        )
        self.max.get_params = lambda: float_check(
            self.lineEdit_max.text(), default=float("inf")
        )
        # Dictionnary (WrapperDict)
        self.dict = OrderedDict([("min", self.min), ("max", self.max)])
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)
        self.show()

    def clear(self):
        self.lineEdit_min.clear()
        self.lineEdit_max.clear()


class RangeLineEdit(QtWidgets.QWidget, Ui_Form_range, WrapperDict):
    """Line edit widget for number range entry.

    Keyword arguments:
    begin -- begin value of the range
    step -- step value of the range
    end -- ending value of the range

    Any entry will initiate the line edit with a string interpretation
    of the arguments.
    This is a Qt derived object.
    """

    def __init__(self, **kwargs):
        super(RangeLineEdit, self).__init__()
        self.id = "range"
        self.setupUi(self)
        self.begin = Wrapper(action=lambda x: self.lineEdit_begin.setText(str_check(x)))
        self.begin.get_params = lambda: float_check(self.lineEdit_begin.text())
        self.step = Wrapper(action=lambda x: self.lineEdit_step.setText(str_check(x)))
        self.step.get_params = lambda: float_check(self.lineEdit_step.text())
        self.end = Wrapper(action=lambda x: self.lineEdit_end.setText(str_check(x)))
        self.end.get_params = lambda: float_check(self.lineEdit_end.text())
        # Dictionnary (WrapperDict)
        self.dict = OrderedDict(
            [("begin", self.begin), ("step", self.step), ("end", self.end)]
        )
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)
        self.show()

    def get_select(self):
        b, s, e = self.get_params().values()
        s = 1 if s is None else s
        try:
            e = e + s if (e - b) % s == 0 else e
            return arange(b, e, s)
        except TypeError:
            return None

    def clear(self):
        self.lineEdit_begin.clear()
        self.lineEdit_step.clear()
        self.lineEdit_end.clear()


class SwitchLineEdit(QtWidgets.QWidget, Ui_Form_switch, WrapperDict):
    """Abstract class."""

    def __init__(self, multiLineEdit, **kwargs):
        super(SwitchLineEdit, self).__init__()
        self.setupUi(self)
        # Init lineEdit objects
        self.scalar = ScalarLineEdit()
        self.multi = multiLineEdit()
        self.focus = Wrapper(self.scalar.id)
        self.id = Wrapper(None)
        # Put them in self
        self.verticalLayout.addWidget(self.scalar)
        self.verticalLayout.addWidget(self.multi)
        # Set initial state
        self._auto_set_visible()
        # Define pushButton behaviour
        self.pushButton.clicked.connect(self._auto_set_visible)
        # Dictionnary
        self.dict = OrderedDict(
            [
                (self.scalar.id, self.scalar),
                (self.multi.id, self.multi),
                ("focus", self.focus),
                ("id", self.id),
            ]
        )
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)
        self.show()

    def _auto_set_visible(self):
        if self.pushButton.isChecked():
            self.scalar.setVisible(False)
            self.multi.setVisible(True)
            self.focus.set_params(self.multi.id)
        else:
            self.multi.setVisible(False)
            self.scalar.setVisible(True)
            self.focus.set_params(self.scalar.id)

    def set_scalar_visible(self, value=True):
        self.pushButton.setChecked(not value)
        self._auto_set_visible()

    def set_focus_on_scalar(self):
        self.set_scalar_visible(True)
        self.scalar.lineEdit.setFocus()

    def set_params(self, **kwargs):
        # self.id = kwargs.get('id', '')
        WrapperDict.set_params(self, **kwargs)
        if self.focus.value == self.scalar.id:
            self.pushButton.setChecked(False)
        else:
            self.pushButton.setChecked(True)
        self._auto_set_visible()

    def get_select(self):
        params = WrapperDict.get_select(self)
        ID = params["focus"]
        return OrderedDict([("id", params["id"]), ("type", ID), ("value", params[ID])])

    def clear(self):
        self.scalar.clear()
        self.multi.clear()


class SwitchScalarBound(SwitchLineEdit):
    """Switcher widget.

    Allows to switch between ScalarLineEdit and BoundLineEdit widgets.

    Keyword arguments:
    scalar -- awaits a dict of keyword arguments for ScalarLineEdit element.
    bound  -- awaits a dict of keyword arguments for BoundLineEdit element.

    Any entry will initiate the line edit elements with a string interpretation
    of the arguments.
    This is a Qt derived object.
    """

    def __init__(self, **kwargs):
        SwitchLineEdit.__init__(self, BoundLineEdit, **kwargs)

    def set_bound_visible(self, value=True):
        self.pushButton.setChecked(value)
        self._auto_set_visible()

    def set_focus_on_bound(self):
        self.set_bound_visible(True)
        self.multi.lineEdit_min.setFocus()


class SwitchScalarRange(SwitchLineEdit):
    """Switcher widget.

    Allows to switch between ScalarLineEdit and RangeLineEdit widgets.

    Keyword arguments:
    scalar -- awaits a dict of keyword arguments for ScalarLineEdit element.
    range  -- awaits a dict of keyword arguments for RangeLineEdit element.

    Any entry will initiate the line edit elements with a string interpretation
    of the arguments.
    This is a Qt derived object.
    """

    def __init__(self, **kwargs):
        SwitchLineEdit.__init__(self, RangeLineEdit, **kwargs)

    def set_range_visible(self, value=True):
        self.pushButton.setChecked(value)
        self._auto_set_visible()

    def set_focus_on_range(self):
        self.set_range_visible(True)
        self.multi.lineEdit_begin.setFocus()


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)

        #        myapp = LineEdit(10)

        #        myapp = StringLineEdit("poulpe")

        #        params = {"min":-1, "max":1}
        #        myapp = BoundLineEdit(**params)

        #        params = {"begin": 1, "end": 8, "step": 2}
        #        myapp = RangeLineEdit(**params)

        #        params = {"bound": {"min": -1, "max": 1},
        #                  "scalar": 5, "focus": "bound"}
        #        params = {"bound": {"min": '-inf', "max": 'inf'},
        #                  "scalar": 5, "focus": "bound"}
        #        myapp = SwitchScalarBound(**params)

        params = {
            "range": {"begin": 1, "step": None, "end": 8},
            "scalar": 5,
            "focus": "range",
            "id": "my id",
        }
        myapp = SwitchScalarRange(**params)

        sys.exit(app.exec_())
    finally:
        print("params=")
        graph_print(myapp.get_params(), indent=2)
        print("select=")
        graph_print(myapp.get_select(), indent=2)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtWidgets, QtGui
from collections import OrderedDict

from eccw_gui.calculator_app.viewers.calculator_main import Ui_Form
from eccw_gui.shared.controllers.lineEdit import SwitchScalarRange
from eccw_gui.shared.controllers.groupBox import GroupBoxContext
from eccw_gui.shared.wrappers import Wrapper, WrapperDict
from eccw_gui.shared.tools import graph_print

from eccw import EccwCompute


class CalculatorController(QtWidgets.QWidget, Ui_Form, WrapperDict):
    def __init__(self, **kwargs):
        super(CalculatorController, self).__init__()
        self.setupUi(self)
        # Init local attributs.
        self.n_digit_rounding = 4
        self.alpha = SwitchScalarRange(id="alpha")
        self.beta = SwitchScalarRange(id="beta")
        self.phiB = SwitchScalarRange(id="phiB")
        self.phiD = SwitchScalarRange(id="phiD")
        self.delta_lambdaB = SwitchScalarRange(id="delta_lambdaB")
        self.delta_lambdaD = SwitchScalarRange(id="delta_lambdaD")
        self.rho_f = SwitchScalarRange(id="rho_f")
        self.rho_sr = SwitchScalarRange(id="rho_sr")
        self.range = Wrapper(None)
        self.compute_core = EccwCompute()
        # List for SwitchScalarRange objects control.
        self.params_list_dry = ("alpha", "beta", "phiB", "phiD")
        self.params_list_fluids = ("delta_lambdaB", "delta_lambdaD", "rho_f", "rho_sr")
        self.param_list_all = [
            "alpha",
            "beta",
            "phiB",
            "phiD",
            "delta_lambdaB",
            "delta_lambdaD",
            "rho_f",
            "rho_sr",
        ]
        self.param_object_list = [
            self.alpha,
            self.beta,
            self.phiB,
            self.phiD,
            self.delta_lambdaB,
            self.delta_lambdaD,
            self.rho_f,
            self.rho_sr,
        ]
        self.context = GroupBoxContext()
        self.results = Wrapper("", action=self._init_results_slider_position)
        self.fluids = Wrapper(
            False,
            process=lambda x: eval(str(x)),
            action=self.groupBox_fluids.setChecked,
        )
        self.fluids_flag_list = ["delta_lambdaB", "delta_lambdaD", "rho_f", "rho_sr"]
        # List of radioButton defining focus
        self.focus_object_list = [
            self.checkBox_alpha,
            self.checkBox_beta,
            self.checkBox_phiB,
            self.checkBox_phiD,
        ]
        self.focus_flag_list = ["alpha", "beta", "phiB", "phiD"]
        for elt, txt in zip(self.focus_object_list, self.focus_flag_list):
            elt.ID = txt
        self.focus = Wrapper("alpha", action=self.set_focus)
        # Put them in self
        self.horizontalLayout_alpha.addWidget(self.alpha)
        self.horizontalLayout_beta.addWidget(self.beta)
        self.horizontalLayout_phiB.addWidget(self.phiB)
        self.horizontalLayout_phiD.addWidget(self.phiD)
        self.horizontalLayout_lamdaB.addWidget(self.delta_lambdaB)
        self.horizontalLayout_lamdaD.addWidget(self.delta_lambdaD)
        self.horizontalLayout_rhof.addWidget(self.rho_f)
        self.horizontalLayout_rhosr.addWidget(self.rho_sr)
        # self.verticalLayout_context.addWidget(self.context)
        self.horizontalLayout_context.addWidget(self.context)
        # Define behaviours
        tmp = lambda elt: lambda: self._there_can_be_only_one(elt)
        for elt in self.param_object_list:
            elt.pushButton.clicked.connect(tmp(elt))
        for elt in self.focus_object_list:
            elt.clicked.connect(self._auto_set_focus)
        self.groupBox_fluids.clicked.connect(self._fluidsChanged)
        self.pushButton_Clear.clicked.connect(self._clean_all)
        self.pushButton_Go.clicked.connect(self.click_compute)
        # Shortcuts for edit parameters.
        self._set_switchLineEdit_shortcuts(self.alpha, "Ctrl+1", "Ctrl+Alt+1")
        self._set_switchLineEdit_shortcuts(self.beta, "Ctrl+2", "Ctrl+Alt+2")
        self._set_switchLineEdit_shortcuts(self.phiB, "Ctrl+3", "Ctrl+Alt+3")
        self._set_switchLineEdit_shortcuts(self.phiD, "Ctrl+4", "Ctrl+Alt+4")
        self._set_switchLineEdit_shortcuts(self.delta_lambdaB, "Ctrl+5", "Ctrl+Alt+5")
        self._set_switchLineEdit_shortcuts(self.delta_lambdaD, "Ctrl+6", "Ctrl+Alt+6")
        self._set_switchLineEdit_shortcuts(self.rho_f, "Ctrl+7", "Ctrl+Alt+7")
        self._set_switchLineEdit_shortcuts(self.rho_sr, "Ctrl+8", "Ctrl+Alt+8")
        # Dictionnary (WrapperDict)
        self.dict = OrderedDict(
            [
                ("context", self.context),
                ("fluids", self.fluids),
                ("focus", self.focus),
                ("range", self.range),
                ("alpha", self.alpha),
                ("beta", self.beta),
                ("phiB", self.phiB),
                ("phiD", self.phiD),
                ("delta_lambdaB", self.delta_lambdaB),
                ("delta_lambdaD", self.delta_lambdaD),
                ("rho_f", self.rho_f),
                ("rho_sr", self.rho_sr),
                ("results", self.results),
            ]
        )
        # Additional variables
        self.name_convert = {
            "alpha": "α",
            "beta": "β",
            "phiB": "Φ<sub>B</sub>",
            "phiD": "Φ<sub>D</sub>",
            "delta_lambdaB": "∆λ<sub>B</sub>",
            "delta_lambdaD": "∆λ<sub>D</sub>",
            "rho_f": "ρ<sub>f</sub>",
            "rho_sr": "ρ<sub>sr</sub>",
        }
        self._result_table_header = self._make_result_table_line(
            [self.name_convert[elt] for elt in self.param_list_all]
        )
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)
        self.show()

    # Methods.

    def _set_switchLineEdit_shortcuts(self, widget, scalar_key, range_key):
        QtWidgets.QShortcut(
            QtGui.QKeySequence(scalar_key), self, widget.set_focus_on_scalar
        )
        QtWidgets.QShortcut(
            QtGui.QKeySequence(range_key),
            self,
            lambda: self._there_can_be_only_one_range_focus(widget),
        )
        widget.pushButton.setToolTip(
            widget.pushButton.toolTip() + f" ({scalar_key} | {range_key})"
        )

    def _init_results_slider_position(self, x):
        self.textEdit_results.setText(x)
        scroll_bar = self.textEdit_results.verticalScrollBar()
        scroll_bar.setSliderPosition(scroll_bar.maximum())

    def _make_result_table_line(self, iterable, arg=""):
        """Format iterable using html tag; return a html table line."""
        td = "<td align='center', " + arg + ">"
        dttd = "</td>" + td
        return "<tr>" + td + dttd.join(iterable) + "</td></tr>"

    def _there_can_be_only_one(self, elt):
        if elt.focus.value == "scalar":
            self.range.value = None
        else:
            self.range.value = elt.id.value
        for Obj in self.param_object_list:
            if Obj is not elt:
                Obj.set_scalar_visible(True)

    def _there_can_be_only_one_range_focus(self, elt):
        elt.set_focus_on_range()
        self._there_can_be_only_one(elt)

    def set_focus(self, arg):
        for elt in self.focus_object_list:
            if elt.ID == arg:
                elt.setChecked(True)
        for elt in self.focus_object_list:
            self.__dict__[elt.ID].setEnabled(not elt.ID == arg)

    def _auto_set_focus(self):
        for elt in self.focus_object_list:
            if elt.isChecked():
                self.focus.value = elt.ID
                break
        for elt in self.focus_object_list:
            self.__dict__[elt.ID].setEnabled(not elt.ID == self.focus.value)

    def _fluidsChanged(self):
        self.fluids.value = self.groupBox_fluids.isChecked()

    def _clean_all(self):
        for elt in self.param_object_list:
            elt.clear()
        self.textEdit_results.clear()

    def click_compute(self):
        txt_result = "<p align='center'>"
        select = self.get_select()
        if select["fluids"]:
            params_list = self.param_list_all
        else:
            params_list = self.params_list_dry
        errors = self._check_arguments(select)
        if errors != "":
            txt_result += errors
        else:
            focus_parameter = self.focus.value
            ranged_parameter = self.range.value
            range_ = (
                [None]
                if ranged_parameter is None or ranged_parameter == focus_parameter
                else select[ranged_parameter]["value"]
            )
            result = []
            try:
                for x in range_:
                    params = {
                        flag: select[flag]["value"] if flag != ranged_parameter else x
                        for flag in params_list
                    }
                    params["context"] = self.context.get_params()
                    self.compute_core.reset()
                    self.compute_core.set_params(**params)
                    result.append(self.compute_core.compute(focus_parameter))
                result = [(i, j, k) for i, (j, k) in zip(range_, result)]
                txt_result += self._format_results(select, result)
            except (TypeError, ValueError) as err:
                txt_result += self._format_raised_error(err)
        txt_result += "<br/></p>"
        self.textEdit_results.append(txt_result)
        self.results.value += txt_result

    def _format_results(self, select, results):
        i = 0 if len(results) > 1 else 1
        txt = self._get_resume_params(select)
        n_rows_max = 5
        n_chars_per_row = 10
        txt += (
            "<table width='"
            + str((n_rows_max - i) * (n_chars_per_row + self.n_digit_rounding))
            + "%'>"
        )
        headers = ("●", "inverse", "normal")
        txt += self._make_result_table_line(headers[i:], arg="style='color: blue'")
        for res in results:
            txt += self._make_result_table_line(
                [
                    self._str_round(elt, self.n_digit_rounding)
                    if elt is not None
                    else "-"
                    for elt in res[i:]
                ]
            )
        txt += "</table>"
        return txt

    def _str_round(self, may_be_iterable, ndigits=None):
        """
        Apply round intrinsic function to
        * floats;
        * iterable containing floats.
        Return a string.
        """
        try:
            return str(round(may_be_iterable, ndigits))
        except TypeError:
            # All this concerns exclusively beta computation.
            if len(may_be_iterable) > 1:
                return ", ".join([str(round(elt, ndigits)) for elt in may_be_iterable])
            elif len(may_be_iterable) == 1:
                return str(round(may_be_iterable[0], ndigits))
            else:
                return "-"

    def _check_arguments(self, select):
        errors = ""
        message = " gets empty or invalid value<br/>"
        focus = self.focus.value
        for p_name in self.focus_flag_list:
            if select[p_name]["value"] is None and p_name != focus:
                errors += self.name_convert[p_name] + message
        if self.fluids.value:
            for p_name in self.fluids_flag_list:
                if select[p_name]["value"] is None:
                    errors += self.name_convert[p_name] + message
        return errors + ""

    def _format_raised_error(self, error):
        error = str(error)[19:]
        i1 = error.find("'")
        i2 = error.find("'", i1 + 1)
        name = self.name_convert[error[i1 + 1 : i2]]
        return error[:i1] + name + error[i2 + 1 :]

    def _get_resume_params(self, select):
        focus = self.focus.value
        context = " " + self.context.get_params() + " "
        n = 50 - len(context)
        title = "-" * n + context + "-" * n
        text = "<table width='100%'>"
        text += self._make_result_table_line(
            [title], arg="colspan='8'," "style='color: blue'"
        )
        text += self._result_table_header
        values = []
        for elt in self.param_list_all:
            value = select[elt]["value"]
            if elt == focus:
                value = "<span style='color: red'>▲</span>"
            elif value is None:
                value = "-"
            elif select[elt]["type"] == "range":
                value = "<span style='color: blue'>●</span>"
            elif not select["fluids"] and elt in self.params_list_fluids:
                value = "-"
            values.append(str(value))
        text += self._make_result_table_line(values)
        text += "</table>"
        return text


if __name__ == "__main__":
    import sys

    try:
        from eccw_gui.shared.file_management import EccwFile

        eccwf = EccwFile(filename="../../../tests/data/test.eccw")
        params = eccwf.values["calculator"]

        app = QtWidgets.QApplication(sys.argv)
        myapp = CalculatorController(**params)
        sys.exit(app.exec_())
    finally:
        print("values :")
        graph_print(myapp.get_select())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/dialog_errors.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog_Errors(object):
    def setupUi(self, Dialog_Errors):
        Dialog_Errors.setObjectName("Dialog_Errors")
        Dialog_Errors.resize(400, 185)
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog_Errors)
        self.verticalLayout.setObjectName("verticalLayout")
        self.textEdit = QtWidgets.QTextEdit(Dialog_Errors)
        self.textEdit.setReadOnly(True)
        self.textEdit.setObjectName("textEdit")
        self.verticalLayout.addWidget(self.textEdit)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.pushButton = QtWidgets.QPushButton(Dialog_Errors)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout.addWidget(self.pushButton)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(Dialog_Errors)
        self.pushButton.clicked.connect(Dialog_Errors.close)
        QtCore.QMetaObject.connectSlotsByName(Dialog_Errors)

    def retranslateUi(self, Dialog_Errors):
        _translate = QtCore.QCoreApplication.translate
        Dialog_Errors.setWindowTitle(_translate("Dialog_Errors", "Errors"))
        self.pushButton.setText(_translate("Dialog_Errors", "Ok"))
        self.pushButton.setShortcut(_translate("Dialog_Errors", "Return"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Dialog_Errors = QtWidgets.QDialog()
    ui = Ui_Dialog_Errors()
    ui.setupUi(Dialog_Errors)
    Dialog_Errors.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/toolButton.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(30, 30)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.toolButton = QtWidgets.QToolButton(Form)
        self.toolButton.setMinimumSize(QtCore.QSize(28, 28))
        self.toolButton.setMaximumSize(QtCore.QSize(28, 28))
        self.toolButton.setBaseSize(QtCore.QSize(28, 28))
        self.toolButton.setToolTip("")
        self.toolButton.setText("")
        self.toolButton.setIconSize(QtCore.QSize(23, 23))
        self.toolButton.setAutoRaise(False)
        self.toolButton.setArrowType(QtCore.Qt.NoArrow)
        self.toolButton.setObjectName("toolButton")
        self.verticalLayout.addWidget(self.toolButton)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtGui, QtWidgets

from eccw_gui.shared.viewers.toolButton import Ui_Form
from eccw_gui.shared.tools import float_check
from eccw_gui.shared.wrappers import Wrapper


class ColorButton(QtWidgets.QWidget, Ui_Form, Wrapper):
    """Color button widget.

    Arguments:
    Awaits a tuple of for reals with value in between 0 and 1 (rgba).

    This is a Qt derived object.
    """

    def __init__(self, *args):
        super(ColorButton, self).__init__()
        self.setupUi(self)
        self.action = lambda x: self.change_color(x)
        self.process = lambda x: x
        self.style_sheet = (
            "color: white;"
            "background-color: %s;"
            "border-style: outset;"
            "border-width: 1;"
            "border-color: gray;"
            "border-radius: 4px;"
            "min-width: 26px;"
            "max-width: 26px;"
            "min-height: 26px;"
            "max-height: 26px;"
        )
        self.style_sheet_hover = "background-color: %s;"
        self.style_sheet_clicked = "border-style: inset;"
        self.setToolTip("Color")
        self.toolButton.clicked.connect(self.showDialog)
        # Fill values with args
        if not args:
            args = (0, 0, 0, 1)  # Default color is black
        self.set_params(args)
        self.show()

    def showDialog(self):
        col = QtWidgets.QColorDialog.getColor()
        if col.isValid():
            self.change_color(col)
            self.value = col.getRgbF()

    def lighter_color(self, col, pct=0.5):
        newcol = QtGui.QColor()
        rgba = tuple(
            i + (1 - i) * pct if i + (1 - i) * pct <= 1 else 1 for i in col.getRgbF()
        )
        newcol.setRgbF(*rgba)
        return newcol

    def change_color(self, color):
        """col is an QColor object"""
        if isinstance(color, tuple):
            col = QtGui.QColor()
            col.setRgbF(*color)
        else:
            col = color
        style = self.style_sheet % col.name()
        # QColor.lighter method doesn't do the way I want the following job:
        col_hover = self.lighter_color(col)
        style_hover = self.style_sheet_hover % col_hover.name()
        self.toolButton.setStyleSheet(
            "QWidget {" + style + "} "
            "QWidget:hover {" + style_hover + "}"
            "QWidget:pressed {" + self.style_sheet_clicked + "}"
        )

    def set_params(self, arg):
        errmessage = "ColorButton() gets invalid color format '" + str(arg) + "'."
        try:
            rgba = tuple(float_check(c) for c in arg)
            if all([c <= 1.0 for c in rgba]) and len(rgba) == 4:
                Wrapper.set_params(self, rgba)
            else:
                raise TypeError(errmessage)
        except TypeError:
            raise TypeError(errmessage)


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)
        myapp = ColorButton("0", "1", "0", "1")
        myapp.set_params(("0", "1", "0", "1"))
        sys.exit(app.exec_())
    finally:
        print("params =", myapp.get_params())
        print("select =", myapp.get_select())



#!/usr/bin/env python3
# -*-coding:utf-8 -*

"""
Base graphic elements used to build the differents parts of the GUI.
Controllers that inherits from form implementation generated from reading ui files and from normalised wrappers that allows automatic and recursive setting/getting.
"""



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Wrappers used on the base elements of the GUI.
They add automated setting and getting of needed parameters.
Wrapped parameters are iteratively setted / gotten.
This allows saving and loading sessions with the GUI.
"""


from collections import OrderedDict


class Wrapper(object):
    """Wrapping non iterable parameter."""

    def __init__(self, arg=None, action=lambda x: None, process=lambda x: x):
        self.process = process
        self.action = action
        self.set_params(arg=arg)

    def get_params(self):
        return self.value

    def set_params(self, arg):
        self.value = self.process(arg)
        self.action(self.value)

    def get_select(self):
        return self.get_params()


class WrapperDict(object):
    """Wrapping parameters stored in a dictionary."""

    def __init__(self, arg=OrderedDict()):
        self.dict = arg

    def get_params(self):
        return OrderedDict([(key, value.get_params()) for key, value
                            in self.dict.items()])

    def set_params(self, **kwargs):
        parser = {key: value.set_params for key, value in self.dict.items()}
        self.check_params(parser, kwargs)

    def get_select(self):
        return OrderedDict([(key, value.get_select()) for key, value
                            in self.dict.items()])

    def check_params(self, parser, params):
        name = self.__class__.__name__
        if isinstance(params, dict):
            try:
                for key, value in params.items():
                    if isinstance(value, dict):
                        parser[key](**value)
                    else:
                        parser[key](value)
            except KeyError:
                raise TypeError(name+"() gets unknown keyword argument '"
                                + str(key) + "'.")
        else:
            raise TypeError(name+"() awaits a dict as argument.")


class WrapperList(object):
    """Wrapping parameters stored in a list."""

    def __init__(self, arg=[]):
        self.list = list(arg)

    def get_params(self):
        return [elt.get_params() for elt in self.list]

    def set_params(self, paramsList):
        for i, params in enumerate(paramsList):
            if isinstance(params, dict):
                self.list[i].set_params(**params)
            else:
                self.list[i].set_params(params)

    def get_select(self):
        return [elt.get_select() for elt in self.list]


if __name__ == "__main__":

    x = "something"
    W = Wrapper(x)
    print(W.get_params())




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/dialog_about.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog_About(object):
    def setupUi(self, Dialog_About):
        Dialog_About.setObjectName("Dialog_About")
        Dialog_About.resize(410, 289)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog_About.sizePolicy().hasHeightForWidth())
        Dialog_About.setSizePolicy(sizePolicy)
        Dialog_About.setMinimumSize(QtCore.QSize(410, 0))
        Dialog_About.setMaximumSize(QtCore.QSize(410, 600))
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(Dialog_About)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(30, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.label_logo = QtWidgets.QLabel(Dialog_About)
        self.label_logo.setMaximumSize(QtCore.QSize(128, 128))
        self.label_logo.setText("")
        self.label_logo.setPixmap(QtGui.QPixmap(":/icons/icon_eccw_128x128.png"))
        self.label_logo.setScaledContents(False)
        self.label_logo.setObjectName("label_logo")
        self.horizontalLayout.addWidget(self.label_logo)
        spacerItem1 = QtWidgets.QSpacerItem(30, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.label_title = QtWidgets.QLabel(Dialog_About)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_title.setFont(font)
        self.label_title.setAlignment(QtCore.Qt.AlignCenter)
        self.label_title.setObjectName("label_title")
        self.verticalLayout_2.addWidget(self.label_title)
        spacerItem2 = QtWidgets.QSpacerItem(191, 13, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem2)
        self.label_url = QtWidgets.QLabel(Dialog_About)
        self.label_url.setTextFormat(QtCore.Qt.AutoText)
        self.label_url.setAlignment(QtCore.Qt.AlignCenter)
        self.label_url.setOpenExternalLinks(True)
        self.label_url.setObjectName("label_url")
        self.verticalLayout_2.addWidget(self.label_url)
        self.label_contact = QtWidgets.QLabel(Dialog_About)
        self.label_contact.setTextFormat(QtCore.Qt.AutoText)
        self.label_contact.setAlignment(QtCore.Qt.AlignCenter)
        self.label_contact.setOpenExternalLinks(True)
        self.label_contact.setObjectName("label_contact")
        self.verticalLayout_2.addWidget(self.label_contact)
        self.horizontalLayout_3.addLayout(self.verticalLayout_2)
        self.line = QtWidgets.QFrame(Dialog_About)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_3.addWidget(self.line)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label1 = QtWidgets.QLabel(Dialog_About)
        self.label1.setMinimumSize(QtCore.QSize(160, 0))
        self.label1.setObjectName("label1")
        self.verticalLayout.addWidget(self.label1)
        self.label_version = QtWidgets.QLabel(Dialog_About)
        self.label_version.setAlignment(QtCore.Qt.AlignCenter)
        self.label_version.setObjectName("label_version")
        self.verticalLayout.addWidget(self.label_version)
        spacerItem3 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem3)
        self.label2 = QtWidgets.QLabel(Dialog_About)
        self.label2.setObjectName("label2")
        self.verticalLayout.addWidget(self.label2)
        self.label_authors = QtWidgets.QLabel(Dialog_About)
        self.label_authors.setAlignment(QtCore.Qt.AlignCenter)
        self.label_authors.setObjectName("label_authors")
        self.verticalLayout.addWidget(self.label_authors)
        spacerItem4 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem4)
        self.label3 = QtWidgets.QLabel(Dialog_About)
        self.label3.setObjectName("label3")
        self.verticalLayout.addWidget(self.label3)
        self.label_license = QtWidgets.QLabel(Dialog_About)
        self.label_license.setAlignment(QtCore.Qt.AlignCenter)
        self.label_license.setObjectName("label_license")
        self.verticalLayout.addWidget(self.label_license)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem5)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem6)
        self.label_2 = QtWidgets.QLabel(Dialog_About)
        self.label_2.setText("")
        self.label_2.setPixmap(QtGui.QPixmap(":/icons/Qt_logo_24x33.png"))
        self.label_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.label = QtWidgets.QLabel(Dialog_About)
        self.label.setText("")
        self.label.setPixmap(QtGui.QPixmap(":/icons/python-powered-60x24.png"))
        self.label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem7)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3.addLayout(self.verticalLayout)

        self.retranslateUi(Dialog_About)
        QtCore.QMetaObject.connectSlotsByName(Dialog_About)

    def retranslateUi(self, Dialog_About):
        _translate = QtCore.QCoreApplication.translate
        Dialog_About.setWindowTitle(_translate("Dialog_About", "About"))
        self.label_title.setText(_translate("Dialog_About", "<html><head/><body><p align=\"center\"><span style=\" font-size:14pt; font-weight:600;\">ECCW</span><br/>Exact Critical Coulomb Wedge</p></body></html>"))
        self.label_url.setText(_translate("Dialog_About", "url"))
        self.label_contact.setText(_translate("Dialog_About", "contact"))
        self.label1.setText(_translate("Dialog_About", "<html><head/><body><p align=\"center\"><span style=\" font-weight:600;\">Version</span></p></body></html>"))
        self.label_version.setText(_translate("Dialog_About", "version"))
        self.label2.setText(_translate("Dialog_About", "<html><head/><body><p align=\"center\"><span style=\" font-weight:600;\">Authors</span></p></body></html>"))
        self.label_authors.setText(_translate("Dialog_About", "authors"))
        self.label3.setText(_translate("Dialog_About", "<html><head/><body><p align=\"center\"><span style=\" font-weight:600;\">License</span></p></body></html>"))
        self.label_license.setText(_translate("Dialog_About", "license"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Dialog_About = QtWidgets.QDialog()
    ui = Ui_Dialog_About()
    ui.setupUi(Dialog_About)
    Dialog_About.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtWidgets

from eccw_gui.shared.viewers.spinBox import Ui_Form
from eccw_gui.shared.tools import float_check


class SpinBox(QtWidgets.QWidget, Ui_Form):
    """Spin box widget.

    Arguments:
    Awaits an integer or a real number that will initiate the state of the
    spin box.

    This is a Qt derived object.
    """

    def __init__(self, *args):
        super(SpinBox, self).__init__()
        self.setupUi(self)
        # Fill values with args
        if args:
            self.set_params(*args)
        self.show()

    def get_params(self):
        return self.doubleSpinBox.value()

    def set_params(self, value):
        errmessage = (
            self.__class__.__name__
            + "() gets invalid size format '"
            + str(value)
            + "'."
        )
        try:
            value = float_check(value, default=None)
            if value < 0:
                raise TypeError(errmessage)
            self.doubleSpinBox.setValue(value)
        except TypeError:
            raise TypeError(errmessage)

    def get_select(self):
        return self.get_params()


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)
        myapp = SpinBox("1.2")
        sys.exit(app.exec_())
    finally:
        print("params =", myapp.get_params())
        print("select =", myapp.get_select())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/main.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(714, 528)
        font = QtGui.QFont()
        font.setKerning(True)
        Form.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/icon_eccw_512x512.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Form.setWindowIcon(icon)
        self.verticalLayout_18 = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self.horizontalLayout_topmenu = QtWidgets.QHBoxLayout()
        self.horizontalLayout_topmenu.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_topmenu.setObjectName("horizontalLayout_topmenu")
        self.pushButton_Open = QtWidgets.QPushButton(Form)
        self.pushButton_Open.setMinimumSize(QtCore.QSize(80, 28))
        self.pushButton_Open.setMaximumSize(QtCore.QSize(80, 28))
        self.pushButton_Open.setBaseSize(QtCore.QSize(80, 28))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/buttons/button_open.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_Open.setIcon(icon1)
        self.pushButton_Open.setIconSize(QtCore.QSize(20, 20))
        self.pushButton_Open.setObjectName("pushButton_Open")
        self.horizontalLayout_topmenu.addWidget(self.pushButton_Open)
        self.pushButton_Save = QtWidgets.QPushButton(Form)
        self.pushButton_Save.setMinimumSize(QtCore.QSize(80, 28))
        self.pushButton_Save.setMaximumSize(QtCore.QSize(80, 28))
        self.pushButton_Save.setBaseSize(QtCore.QSize(80, 28))
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/buttons/button_save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_Save.setIcon(icon2)
        self.pushButton_Save.setIconSize(QtCore.QSize(20, 20))
        self.pushButton_Save.setObjectName("pushButton_Save")
        self.horizontalLayout_topmenu.addWidget(self.pushButton_Save)
        self.line_2 = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.line_2.sizePolicy().hasHeightForWidth())
        self.line_2.setSizePolicy(sizePolicy)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout_topmenu.addWidget(self.line_2)
        self.pushButton_About = QtWidgets.QPushButton(Form)
        self.pushButton_About.setMinimumSize(QtCore.QSize(80, 28))
        self.pushButton_About.setMaximumSize(QtCore.QSize(80, 28))
        self.pushButton_About.setBaseSize(QtCore.QSize(80, 28))
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/buttons/button_about.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_About.setIcon(icon3)
        self.pushButton_About.setIconSize(QtCore.QSize(20, 20))
        self.pushButton_About.setObjectName("pushButton_About")
        self.horizontalLayout_topmenu.addWidget(self.pushButton_About)
        self.pushButton_Documentation = QtWidgets.QPushButton(Form)
        self.pushButton_Documentation.setMinimumSize(QtCore.QSize(140, 28))
        self.pushButton_Documentation.setMaximumSize(QtCore.QSize(140, 28))
        self.pushButton_Documentation.setBaseSize(QtCore.QSize(140, 28))
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/buttons/button_documentation.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_Documentation.setIcon(icon4)
        self.pushButton_Documentation.setIconSize(QtCore.QSize(20, 20))
        self.pushButton_Documentation.setObjectName("pushButton_Documentation")
        self.horizontalLayout_topmenu.addWidget(self.pushButton_Documentation)
        self.verticalLayout_18.addLayout(self.horizontalLayout_topmenu)
        self.tabWidget_main = QtWidgets.QTabWidget(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget_main.sizePolicy().hasHeightForWidth())
        self.tabWidget_main.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.tabWidget_main.setFont(font)
        self.tabWidget_main.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        self.tabWidget_main.setAutoFillBackground(True)
        self.tabWidget_main.setTabPosition(QtWidgets.QTabWidget.South)
        self.tabWidget_main.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.tabWidget_main.setIconSize(QtCore.QSize(20, 20))
        self.tabWidget_main.setElideMode(QtCore.Qt.ElideLeft)
        self.tabWidget_main.setDocumentMode(True)
        self.tabWidget_main.setTabsClosable(False)
        self.tabWidget_main.setObjectName("tabWidget_main")
        self.tab_calculator = QtWidgets.QWidget()
        self.tab_calculator.setAutoFillBackground(True)
        self.tab_calculator.setObjectName("tab_calculator")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/tabs/tab_calculate.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabWidget_main.addTab(self.tab_calculator, icon5, "")
        self.tab_plot = QtWidgets.QWidget()
        self.tab_plot.setAutoFillBackground(True)
        self.tab_plot.setObjectName("tab_plot")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/tabs/tab_plot.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabWidget_main.addTab(self.tab_plot, icon6, "")
        self.verticalLayout_18.addWidget(self.tabWidget_main)

        self.retranslateUi(Form)
        self.tabWidget_main.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "ECCW"))
        self.pushButton_Open.setToolTip(_translate("Form", "Open previously saved session (Crtl+O)"))
        self.pushButton_Open.setText(_translate("Form", "&Open"))
        self.pushButton_Open.setShortcut(_translate("Form", "Ctrl+O"))
        self.pushButton_Save.setToolTip(_translate("Form", "Save current session (Crtl+S)"))
        self.pushButton_Save.setText(_translate("Form", "&Save"))
        self.pushButton_Save.setShortcut(_translate("Form", "Ctrl+S"))
        self.pushButton_About.setToolTip(_translate("Form", "About ECCW software"))
        self.pushButton_About.setText(_translate("Form", "About"))
        self.pushButton_Documentation.setToolTip(_translate("Form", "Display pdf fulll documentation"))
        self.pushButton_Documentation.setText(_translate("Form", "Documentation"))
        self.tabWidget_main.setTabText(self.tabWidget_main.indexOf(self.tab_calculator), _translate("Form", "Calculator                    "))
        self.tabWidget_main.setTabText(self.tabWidget_main.indexOf(self.tab_plot), _translate("Form", "Plot                              "))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtWidgets
from collections import OrderedDict

from eccw_gui.plot_app.viewers.curve_graphicSettings import Ui_Form
from eccw_gui.shared.controllers.label import Label
from eccw_gui.shared.controllers.spinBox import SpinBox
from eccw_gui.shared.controllers.colorButton import ColorButton
from eccw_gui.shared.controllers.layout import VerticalLayout
from eccw_gui.shared.controllers.comboBox import ComboBoxLine, ComboBoxColorMap
from eccw_gui.shared.wrappers import Wrapper, WrapperDict
from eccw_gui.shared.tools import graph_print


class CurveGraphicSettings(QtWidgets.QWidget, Ui_Form, WrapperDict):
    """Widget for curve settings entry.

    Keyword arguments:
    thickness -- awaits a dict of keyword arguments for a ScalarLineEdit
                 element.
    color     -- awaits a dict of keyword arguments for a ColorButton element.
    colormap  -- awaits a dict of keyword arguments for a ColorBoxColorMap
                 element.
    style     -- awaits a dict of keyword arguments for a ComboBoxLine element.

    note: color and colormap keyword arguments are exclusives.
    This is a Qt derived object.
    """

    def __init__(self, label=False, **kwargs):
        super(CurveGraphicSettings, self).__init__()
        self.setupUi(self)
        # Init additional objects
        if kwargs:
            colormap = kwargs.get("colormap", False)
            color = kwargs.get("color", False)
        else:
            color, colormap = False, False
        if color and colormap:
            raise TypeError(
                "CurveGraphicSettings() awaits 'color' OR"
                "'colomap' arguments, not both."
            )
        self.labelThick = Label("thickness")
        self.size = SpinBox()
        if colormap:
            self.color = ComboBoxColorMap()
        else:
            self.color = ColorButton()
        self.style = ComboBoxLine()
        # Put them in self
        self.horizontalLayout.addWidget(self.labelThick)
        self.horizontalLayout.addWidget(self.size)
        self.horizontalLayout.addWidget(self.color)
        self.horizontalLayout.addWidget(self.style)
        # Dictionnary (WrapperDict)
        self.dict = OrderedDict(
            [
                ("thickness", self.size),
                ("colormap" if colormap else "color", self.color),
                ("style", self.style),
            ]
        )
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)
        if label:
            self.flagLabel = Label(label, bold=True)
            self.horizontalLayout.addWidget(self.flagLabel)
        self.show()


class CurveDoubleGraphicSettings(VerticalLayout, WrapperDict):
    """Widget for a two parts curve settings entry.

    Keyword arguments:
    normal  -- awaits a dict of keyword arguments for a CurveGraphicSettings
               element (with 'color' kwarg).
    inverse -- awaits a dict of keyword arguments for a CurveGraphicSettings
               element (with 'color' kwarg).

    This is a Qt derived object.
    """

    def __init__(self, **kwargs):
        VerticalLayout.__init__(self)
        self.normal = CurveGraphicSettings(label="normal", color=(0, 0, 1, 1))
        self.inverse = CurveGraphicSettings(label="inverse", color=(1, 0, 0, 1))
        self.verticalLayout.addWidget(self.normal)
        self.verticalLayout.addWidget(self.inverse)
        # Dictionnary (WrapperDict)
        self.dict = OrderedDict([("normal", self.normal), ("inverse", self.inverse)])
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)


class SwitchCurveGraphicSettings(VerticalLayout, WrapperDict):
    """Switcher widget.

    Allows to switch between the following elements:
    * CurveGraphicSettings with 'color' element,
    * CurveGraphicSettings with 'colormap' element,
    * CurveDoubleGraphicSettings.

    Keyword arguments:
    focus   -- awaits a string among 'default', 'double', 'range'.
    default -- awaits a dict of keyword arguments for CurveGraphicSettings
               element with color element.
    double  -- awaits a dict of keyword arguments for
               CurveDoubleGraphicSettings element.
    range   -- awaits a dict of keyword arguments for CurveGraphicSettings
               element with colormap element.

    This is a Qt derived object.
    """

    def __init__(self, **kwargs):
        VerticalLayout.__init__(self)
        # Init additional objects
        self.focus = Wrapper()
        self.default = CurveGraphicSettings()
        self.range = CurveGraphicSettings(colormap="Gray")
        self.double = CurveDoubleGraphicSettings()
        # Put them in self
        self.verticalLayout.addWidget(self.default)
        self.verticalLayout.addWidget(self.double)
        self.verticalLayout.addWidget(self.range)
        # Initial state
        self.set_visible_manual("default")
        # Dictionnary (WrapperDict)
        self.dict = OrderedDict(
            [
                ("focus", self.focus),
                ("default", self.default),
                ("double", self.double),
                ("range", self.range),
            ]
        )
        # Fill values with kwargs
        if kwargs:
            self.set_params(**kwargs)

    def set_visible_manual(self, arg):
        self.default.setVisible(arg == "default")
        self.double.setVisible(arg == "double")
        self.range.setVisible(arg == "range")
        # self.setGeometry(10, 10, 300, 200)
        self.focus.set_params(arg)

    def set_params(self, **kwargs):
        WrapperDict.set_params(self, **kwargs)
        self.set_visible_manual(self.focus.value)

    def get_select(self):
        params = WrapperDict.get_select(self)
        ID = params["focus"]
        return OrderedDict([("type", ID), ("value", params[ID])])


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)

        p1 = {"thickness": 3.0, "style": "dashed", "color": (1, 0, 0, 1)}
        p2 = {"thickness": 3.0, "style": "dotted", "color": (1, 0, 1, 1)}
        # myapp = CurveGraphicSettings(**p1, label="poulpe")

        pr = {"thickness": 3.0, "style": "dashed", "colormap": "Inferno"}
        # myapp = CurveGraphicSettings(**pr)

        pd = {"normal": p1, "inverse": p2}
        # myapp = CurveDoubleGraphicSettings(**pd)

        params = {"default": p1, "range": pr, "double": pd, "focus": "double"}
        myapp = SwitchCurveGraphicSettings(**params)
        sys.exit(app.exec_())
    finally:
        print("params =")
        graph_print(myapp.get_params())
        print("select =")
        graph_print(myapp.get_select())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/lineEdit_range.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(120, 28)
        Form.setMaximumSize(QtCore.QSize(120, 16777215))
        self.horizontalLayout = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lineEdit_begin = QtWidgets.QLineEdit(Form)
        self.lineEdit_begin.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_begin.sizePolicy().hasHeightForWidth())
        self.lineEdit_begin.setSizePolicy(sizePolicy)
        self.lineEdit_begin.setMinimumSize(QtCore.QSize(40, 28))
        self.lineEdit_begin.setMaximumSize(QtCore.QSize(40, 28))
        self.lineEdit_begin.setBaseSize(QtCore.QSize(40, 28))
        self.lineEdit_begin.setWhatsThis("")
        self.lineEdit_begin.setText("")
        self.lineEdit_begin.setObjectName("lineEdit_begin")
        self.horizontalLayout.addWidget(self.lineEdit_begin)
        self.lineEdit_step = QtWidgets.QLineEdit(Form)
        self.lineEdit_step.setMinimumSize(QtCore.QSize(40, 28))
        self.lineEdit_step.setMaximumSize(QtCore.QSize(40, 28))
        self.lineEdit_step.setBaseSize(QtCore.QSize(40, 28))
        self.lineEdit_step.setText("")
        self.lineEdit_step.setAlignment(QtCore.Qt.AlignCenter)
        self.lineEdit_step.setObjectName("lineEdit_step")
        self.horizontalLayout.addWidget(self.lineEdit_step)
        self.lineEdit_end = QtWidgets.QLineEdit(Form)
        self.lineEdit_end.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_end.sizePolicy().hasHeightForWidth())
        self.lineEdit_end.setSizePolicy(sizePolicy)
        self.lineEdit_end.setMinimumSize(QtCore.QSize(40, 28))
        self.lineEdit_end.setMaximumSize(QtCore.QSize(40, 28))
        self.lineEdit_end.setBaseSize(QtCore.QSize(40, 28))
        self.lineEdit_end.setText("")
        self.lineEdit_end.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_end.setObjectName("lineEdit_end")
        self.horizontalLayout.addWidget(self.lineEdit_end)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.lineEdit_begin.setToolTip(_translate("Form", "Interval begin"))
        self.lineEdit_step.setToolTip(_translate("Form", "Interval step"))
        self.lineEdit_end.setToolTip(_translate("Form", "Interval end"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*-coding:utf-8 -*

from setuptools import setup, find_packages
import sys
from distutils.command.install_data import install_data
import subprocess
import os

def get_data_files():
    """Return data_files in a platform dependent manner"""
    if sys.platform.startswith("linux"):
        data_files = [
            ("share/applications", ["scripts/eccw.desktop"]),
            ("share/pixmaps", [
                "eccw_gui/images/icon_eccw.svg",
                "eccw_gui/images/icon_eccw.ico",
            ]),
            ("share/metainfo", ["scripts/eccw.appdata.xml"]),
        ]
    else:
        data_files = [
            ("share/pixmaps", [
                "eccw_gui/images/icon_eccw.svg",
                "eccw_gui/images/icon_eccw.ico",
            ]),
        ]
    return data_files

# Make Linux detect ECCW desktop file
class MyInstallData(install_data):
    def run(self):
        install_data.run(self)
        if sys.platform.startswith("linux"):
            try:
                subprocess.call(["update-desktop-database"])
            except:
                print("ERROR: unable to update desktop database", file=sys.stderr)

CMDCLASS = {"install_data": MyInstallData}

SCRIPTS = ["eccw", "eccw_win_post_install2.py"]
#SCRIPTS = ["eccw"]
#if sys.platform.startswith('linux'):
#    SCRIPTS.append("eccw")

setup(
    entry_points={"console_scripts": ["eccw=eccw_gui.main:launch"]},
    data_files=get_data_files(),
    #scripts=[os.path.join("scripts", "eccw")],
    scripts=[os.path.join('scripts', fname) for fname in SCRIPTS],
    cmdclass=CMDCLASS,
)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/comboBox_colorMap.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(130, 30)
        Form.setMinimumSize(QtCore.QSize(130, 0))
        self.horizontalLayout = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.comboBox = QtWidgets.QComboBox(Form)
        self.comboBox.setMinimumSize(QtCore.QSize(130, 28))
        self.comboBox.setMaximumSize(QtCore.QSize(130, 28))
        self.comboBox.setBaseSize(QtCore.QSize(130, 28))
        self.comboBox.setIconSize(QtCore.QSize(35, 20))
        self.comboBox.setDuplicatesEnabled(False)
        self.comboBox.setFrame(True)
        self.comboBox.setObjectName("comboBox")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/colormaps/colormap_gray.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.comboBox.addItem(icon, "")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/colormaps/colormap_hot.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.comboBox.addItem(icon1, "")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/colormaps/colormap_winter.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.comboBox.addItem(icon2, "")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/colormaps/colormap_gnuplot.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.comboBox.addItem(icon3, "")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/colormaps/colormap_gnuplot2.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.comboBox.addItem(icon4, "")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/colormaps/colormap_magma.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.comboBox.addItem(icon5, "")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/colormaps/colormap_inferno.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.comboBox.addItem(icon6, "")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/colormaps/colormap_plasma.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.comboBox.addItem(icon7, "")
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/colormaps/colormap_viridis.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.comboBox.addItem(icon8, "")
        self.horizontalLayout.addWidget(self.comboBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.comboBox.setToolTip(_translate("Form", "Lines colormap"))
        self.comboBox.setItemText(0, _translate("Form", "Gray"))
        self.comboBox.setItemText(1, _translate("Form", "Hot"))
        self.comboBox.setItemText(2, _translate("Form", "Winter"))
        self.comboBox.setItemText(3, _translate("Form", "Gnuplot"))
        self.comboBox.setItemText(4, _translate("Form", "Gnuplot2"))
        self.comboBox.setItemText(5, _translate("Form", "Magma"))
        self.comboBox.setItemText(6, _translate("Form", "Inferno"))
        self.comboBox.setItemText(7, _translate("Form", "Plasma"))
        self.comboBox.setItemText(8, _translate("Form", "Viridis"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtGui, QtWidgets

from eccw_gui.shared.viewers.label import Ui_Form


class Label(QtWidgets.QWidget, Ui_Form):
    """Label widget.

    Arguments:
    Awaits any string value.

    This is a Qt derived object.
    """

    def __init__(self, *args, **kwargs):
        super(Label, self).__init__()
        self.id = "scalar"
        self.setupUi(self)
        if kwargs.get("bold", False):
            self.setBold(kwargs["bold"])
        # Fill values with args
        if args:
            self.set_params(args[0])
        self.show()

    def setBold(self, arg):
        font = QtGui.QFont()
        font.setWeight(50)
        font.setBold(arg)
        self.label.setFont(font)

    def get_params(self):
        return self.label.text()

    def set_params(self, value):
        self.label.setText(str(value))

    def get_select(self):
        return self.get_params()

    def clear(self):
        self.label.clear()


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)
        myapp = Label("poulpe", bold=True)
        sys.exit(app.exec_())
    finally:
        print("params =", myapp.get_params())
        print("select =", myapp.get_select())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/lineEdit_bound.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(120, 28)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        Form.setMaximumSize(QtCore.QSize(200, 16777215))
        self.horizontalLayout = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lineEdit_min = QtWidgets.QLineEdit(Form)
        self.lineEdit_min.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_min.sizePolicy().hasHeightForWidth())
        self.lineEdit_min.setSizePolicy(sizePolicy)
        self.lineEdit_min.setMinimumSize(QtCore.QSize(40, 28))
        self.lineEdit_min.setMaximumSize(QtCore.QSize(40, 28))
        self.lineEdit_min.setBaseSize(QtCore.QSize(40, 28))
        self.lineEdit_min.setText("")
        self.lineEdit_min.setObjectName("lineEdit_min")
        self.horizontalLayout.addWidget(self.lineEdit_min)
        self.label_1 = QtWidgets.QLabel(Form)
        self.label_1.setMinimumSize(QtCore.QSize(10, 28))
        self.label_1.setMaximumSize(QtCore.QSize(10, 28))
        self.label_1.setBaseSize(QtCore.QSize(10, 28))
        self.label_1.setAlignment(QtCore.Qt.AlignCenter)
        self.label_1.setObjectName("label_1")
        self.horizontalLayout.addWidget(self.label_1)
        self.lineEdit = QtWidgets.QLineEdit(Form)
        self.lineEdit.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit.sizePolicy().hasHeightForWidth())
        self.lineEdit.setSizePolicy(sizePolicy)
        self.lineEdit.setMinimumSize(QtCore.QSize(20, 28))
        self.lineEdit.setMaximumSize(QtCore.QSize(20, 28))
        self.lineEdit.setBaseSize(QtCore.QSize(20, 28))
        self.lineEdit.setToolTip("")
        self.lineEdit.setText("")
        self.lineEdit.setObjectName("lineEdit")
        self.horizontalLayout.addWidget(self.lineEdit)
        self.label_2 = QtWidgets.QLabel(Form)
        self.label_2.setMinimumSize(QtCore.QSize(10, 28))
        self.label_2.setMaximumSize(QtCore.QSize(10, 28))
        self.label_2.setBaseSize(QtCore.QSize(10, 28))
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.lineEdit_max = QtWidgets.QLineEdit(Form)
        self.lineEdit_max.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_max.sizePolicy().hasHeightForWidth())
        self.lineEdit_max.setSizePolicy(sizePolicy)
        self.lineEdit_max.setMinimumSize(QtCore.QSize(40, 28))
        self.lineEdit_max.setMaximumSize(QtCore.QSize(40, 28))
        self.lineEdit_max.setBaseSize(QtCore.QSize(40, 28))
        self.lineEdit_max.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.lineEdit_max.setText("")
        self.lineEdit_max.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_max.setObjectName("lineEdit_max")
        self.horizontalLayout.addWidget(self.lineEdit_max)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.lineEdit_min.setToolTip(_translate("Form", "Minimal value"))
        self.label_1.setText(_translate("Form", "<"))
        self.label_2.setText(_translate("Form", "<"))
        self.lineEdit_max.setToolTip(_translate("Form", "Maximal value"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtCore, QtWidgets, QtGui

from eccw_gui.plot_app.viewers.plot_window import Ui_PlotWindow

from matplotlib.backends.backend_qt5agg import FigureCanvas
from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT


class PlotWindow(QtWidgets.QWidget, Ui_PlotWindow):
    """Widget for software informations display."""

    def __init__(self, figure=None):
        super(PlotWindow, self).__init__()
        self.setupUi(self)
        # self.setWindowTitle("ECCW plot")
        self.figure = figure
        self.axe = self.figure.gca()
        self.plotWidget = FigureCanvas(self.figure)
        self.plotWidget.updateGeometry()
        self.verticalLayout_plot.addWidget(self.plotWidget)
        self.toolbarwidget = NavigationToolbar2QT(self.plotWidget, self)
        self.verticalLayout_toolbox.addWidget(self.toolbarwidget)
        QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+W"), self, self.close)

    def update(self):
        self.plotWidget.draw()


if __name__ == "__main__":
    import sys
    import random
    from matplotlib.figure import Figure

    app = QtWidgets.QApplication(sys.argv)
    data = [random.random() for i in range(25)]
    figure = Figure(figsize=(5, 4), dpi=100)
    axe = figure.gca()
    axe.plot(data, "r-")
    axe.set_title("PyQt Matplotlib Example")
    myapp = PlotWindow(figure=figure)
    myapp.show()
    sys.exit(app.exec_())



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import QtWidgets

from eccw_gui.shared.viewers.groupBox_context import Ui_Form as UiContext


class GroupBoxContext(QtWidgets.QWidget, UiContext):
    """Check box widget for tectonic context settings.

    Arguments:
    Awaits a single string value among the following list
    * Compression
    * Extension

    This is a Qt derived object.
    """

    def __init__(self, *args):
        super(GroupBoxContext, self).__init__()
        self.setupUi(self)
        # Fill values with args
        if args:
            self.set_params(*args)
        self.show()

    def set_params(self, value):
        if value == "Compression":
            self.checkBox_compression.setChecked(True)
        if value == "Extension":
            self.checkBox_extension.setChecked(True)

    def get_params(self):
        if self.checkBox_compression.isChecked():
            return "Compression"
        if self.checkBox_extension.isChecked():
            return "Extension"

    def get_select(self):
        if self.checkBox_compression.isChecked():
            return "c"
        if self.checkBox_extension.isChecked():
            return "e"


if __name__ == "__main__":
    import sys

    try:
        app = QtWidgets.QApplication(sys.argv)
        myapp = GroupBoxContext("Extension")
        sys.exit(app.exec_())
    finally:
        print("params =", myapp.get_params())
        print("select =", myapp.get_select())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/curve_settings.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(901, 269)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.horizontalLayout_context = QtWidgets.QHBoxLayout()
        self.horizontalLayout_context.setObjectName("horizontalLayout_context")
        self.horizontalLayout_11.addLayout(self.horizontalLayout_context)
        self.groupBox_friction = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_friction.sizePolicy().hasHeightForWidth())
        self.groupBox_friction.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.groupBox_friction.setFont(font)
        self.groupBox_friction.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.groupBox_friction.setCheckable(False)
        self.groupBox_friction.setChecked(False)
        self.groupBox_friction.setObjectName("groupBox_friction")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_friction)
        self.gridLayout.setObjectName("gridLayout")
        self.label_phiD = QtWidgets.QLabel(self.groupBox_friction)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_phiD.sizePolicy().hasHeightForWidth())
        self.label_phiD.setSizePolicy(sizePolicy)
        self.label_phiD.setMaximumSize(QtCore.QSize(20, 24))
        self.label_phiD.setPixmap(QtGui.QPixmap(":/params/params_phiD.png"))
        self.label_phiD.setScaledContents(True)
        self.label_phiD.setObjectName("label_phiD")
        self.gridLayout.addWidget(self.label_phiD, 1, 1, 1, 1)
        self.label_phiB = QtWidgets.QLabel(self.groupBox_friction)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_phiB.sizePolicy().hasHeightForWidth())
        self.label_phiB.setSizePolicy(sizePolicy)
        self.label_phiB.setMaximumSize(QtCore.QSize(20, 24))
        self.label_phiB.setText("")
        self.label_phiB.setPixmap(QtGui.QPixmap(":/params/params_phiB.png"))
        self.label_phiB.setScaledContents(True)
        self.label_phiB.setObjectName("label_phiB")
        self.gridLayout.addWidget(self.label_phiB, 0, 1, 1, 1)
        self.horizontalLayout_phiD = QtWidgets.QHBoxLayout()
        self.horizontalLayout_phiD.setSpacing(0)
        self.horizontalLayout_phiD.setObjectName("horizontalLayout_phiD")
        self.gridLayout.addLayout(self.horizontalLayout_phiD, 1, 2, 1, 1)
        self.horizontalLayout_phiB = QtWidgets.QHBoxLayout()
        self.horizontalLayout_phiB.setSpacing(0)
        self.horizontalLayout_phiB.setObjectName("horizontalLayout_phiB")
        self.gridLayout.addLayout(self.horizontalLayout_phiB, 0, 2, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_friction)
        self.label.setMaximumSize(QtCore.QSize(6, 24))
        self.label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBox_friction)
        self.label_2.setMaximumSize(QtCore.QSize(6, 24))
        self.label_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
        self.horizontalLayout_11.addWidget(self.groupBox_friction)
        self.groupBox_fluids = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_fluids.sizePolicy().hasHeightForWidth())
        self.groupBox_fluids.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.groupBox_fluids.setFont(font)
        self.groupBox_fluids.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.groupBox_fluids.setCheckable(True)
        self.groupBox_fluids.setChecked(False)
        self.groupBox_fluids.setObjectName("groupBox_fluids")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_fluids)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_rhosr = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_rhosr.sizePolicy().hasHeightForWidth())
        self.label_rhosr.setSizePolicy(sizePolicy)
        self.label_rhosr.setMaximumSize(QtCore.QSize(24, 24))
        self.label_rhosr.setText("")
        self.label_rhosr.setPixmap(QtGui.QPixmap(":/params/params_rhosr.png"))
        self.label_rhosr.setScaledContents(True)
        self.label_rhosr.setObjectName("label_rhosr")
        self.gridLayout_2.addWidget(self.label_rhosr, 1, 4, 1, 1)
        self.horizontalLayout_rhof = QtWidgets.QHBoxLayout()
        self.horizontalLayout_rhof.setSpacing(0)
        self.horizontalLayout_rhof.setObjectName("horizontalLayout_rhof")
        self.gridLayout_2.addLayout(self.horizontalLayout_rhof, 0, 5, 1, 1)
        self.horizontalLayout_lamdaB = QtWidgets.QHBoxLayout()
        self.horizontalLayout_lamdaB.setSpacing(0)
        self.horizontalLayout_lamdaB.setObjectName("horizontalLayout_lamdaB")
        self.gridLayout_2.addLayout(self.horizontalLayout_lamdaB, 0, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_3.setMaximumSize(QtCore.QSize(6, 24))
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 0, 0, 1, 1)
        self.horizontalLayout_rhosr = QtWidgets.QHBoxLayout()
        self.horizontalLayout_rhosr.setSpacing(0)
        self.horizontalLayout_rhosr.setObjectName("horizontalLayout_rhosr")
        self.gridLayout_2.addLayout(self.horizontalLayout_rhosr, 1, 5, 1, 1)
        self.label_lamdaD = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_lamdaD.sizePolicy().hasHeightForWidth())
        self.label_lamdaD.setSizePolicy(sizePolicy)
        self.label_lamdaD.setMaximumSize(QtCore.QSize(30, 24))
        self.label_lamdaD.setText("")
        self.label_lamdaD.setPixmap(QtGui.QPixmap(":/params/params_lamdaD.png"))
        self.label_lamdaD.setScaledContents(True)
        self.label_lamdaD.setObjectName("label_lamdaD")
        self.gridLayout_2.addWidget(self.label_lamdaD, 1, 1, 1, 1)
        self.label_lamdaB = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_lamdaB.sizePolicy().hasHeightForWidth())
        self.label_lamdaB.setSizePolicy(sizePolicy)
        self.label_lamdaB.setMaximumSize(QtCore.QSize(30, 24))
        self.label_lamdaB.setPixmap(QtGui.QPixmap(":/params/params_lamdaB.png"))
        self.label_lamdaB.setScaledContents(True)
        self.label_lamdaB.setObjectName("label_lamdaB")
        self.gridLayout_2.addWidget(self.label_lamdaB, 0, 1, 1, 1)
        self.horizontalLayout_lamdaD = QtWidgets.QHBoxLayout()
        self.horizontalLayout_lamdaD.setSpacing(0)
        self.horizontalLayout_lamdaD.setObjectName("horizontalLayout_lamdaD")
        self.gridLayout_2.addLayout(self.horizontalLayout_lamdaD, 1, 2, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_4.setMaximumSize(QtCore.QSize(6, 24))
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 1, 0, 1, 1)
        self.label_rhof = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_rhof.sizePolicy().hasHeightForWidth())
        self.label_rhof.setSizePolicy(sizePolicy)
        self.label_rhof.setMaximumSize(QtCore.QSize(24, 24))
        self.label_rhof.setText("")
        self.label_rhof.setPixmap(QtGui.QPixmap(":/params/params_rhof.png"))
        self.label_rhof.setScaledContents(True)
        self.label_rhof.setObjectName("label_rhof")
        self.gridLayout_2.addWidget(self.label_rhof, 0, 4, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_5.setMinimumSize(QtCore.QSize(12, 0))
        self.label_5.setMaximumSize(QtCore.QSize(12, 24))
        self.label_5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 0, 3, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_6.setMinimumSize(QtCore.QSize(12, 0))
        self.label_6.setMaximumSize(QtCore.QSize(12, 24))
        self.label_6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 1, 3, 1, 1)
        self.horizontalLayout_11.addWidget(self.groupBox_fluids)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_11.addItem(spacerItem)
        self.dummyVerticalLayout = QtWidgets.QVBoxLayout()
        self.dummyVerticalLayout.setObjectName("dummyVerticalLayout")
        self.pushButton_kill = QtWidgets.QPushButton(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_kill.sizePolicy().hasHeightForWidth())
        self.pushButton_kill.setSizePolicy(sizePolicy)
        self.pushButton_kill.setMinimumSize(QtCore.QSize(28, 28))
        self.pushButton_kill.setMaximumSize(QtCore.QSize(28, 28))
        self.pushButton_kill.setBaseSize(QtCore.QSize(28, 28))
        self.pushButton_kill.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/buttons/button_close.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_kill.setIcon(icon)
        self.pushButton_kill.setObjectName("pushButton_kill")
        self.dummyVerticalLayout.addWidget(self.pushButton_kill)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.dummyVerticalLayout.addItem(spacerItem1)
        self.horizontalLayout_11.addLayout(self.dummyVerticalLayout)
        self.verticalLayout.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_curve = QtWidgets.QHBoxLayout()
        self.horizontalLayout_curve.setObjectName("horizontalLayout_curve")
        self.checkBox_splittedCurves = QtWidgets.QCheckBox(Form)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.checkBox_splittedCurves.setFont(font)
        self.checkBox_splittedCurves.setObjectName("checkBox_splittedCurves")
        self.horizontalLayout_curve.addWidget(self.checkBox_splittedCurves)
        self.checkBox_reverseColormap = QtWidgets.QCheckBox(Form)
        self.checkBox_reverseColormap.setEnabled(False)
        self.checkBox_reverseColormap.setObjectName("checkBox_reverseColormap")
        self.horizontalLayout_curve.addWidget(self.checkBox_reverseColormap)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_curve.addItem(spacerItem2)
        self.verticalLayout.addLayout(self.horizontalLayout_curve)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.verticalLayout_settings = QtWidgets.QVBoxLayout()
        self.verticalLayout_settings.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_settings.setSpacing(0)
        self.verticalLayout_settings.setObjectName("verticalLayout_settings")
        self.horizontalLayout_6.addLayout(self.verticalLayout_settings)
        self.horizontalLayout_label = QtWidgets.QHBoxLayout()
        self.horizontalLayout_label.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_label.setObjectName("horizontalLayout_label")
        self.horizontalLayout_6.addLayout(self.horizontalLayout_label)
        spacerItem3 = QtWidgets.QSpacerItem(150, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem3)
        self.verticalLayout.addLayout(self.horizontalLayout_6)
        spacerItem4 = QtWidgets.QSpacerItem(20, 25, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem4)
        self.horizontalLayout_curvepoints = QtWidgets.QHBoxLayout()
        self.horizontalLayout_curvepoints.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_curvepoints.setObjectName("horizontalLayout_curvepoints")
        self.pushButton_addCurvePoint = QtWidgets.QPushButton(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_addCurvePoint.sizePolicy().hasHeightForWidth())
        self.pushButton_addCurvePoint.setSizePolicy(sizePolicy)
        self.pushButton_addCurvePoint.setMinimumSize(QtCore.QSize(28, 28))
        self.pushButton_addCurvePoint.setMaximumSize(QtCore.QSize(28, 28))
        self.pushButton_addCurvePoint.setBaseSize(QtCore.QSize(28, 28))
        self.pushButton_addCurvePoint.setObjectName("pushButton_addCurvePoint")
        self.horizontalLayout_curvepoints.addWidget(self.pushButton_addCurvePoint)
        self.label_CurvePoint = QtWidgets.QLabel(Form)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_CurvePoint.setFont(font)
        self.label_CurvePoint.setObjectName("label_CurvePoint")
        self.horizontalLayout_curvepoints.addWidget(self.label_CurvePoint)
        self.line = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.line.sizePolicy().hasHeightForWidth())
        self.line.setSizePolicy(sizePolicy)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_curvepoints.addWidget(self.line)
        self.pushButton_killAllCurvePoints = QtWidgets.QPushButton(Form)
        self.pushButton_killAllCurvePoints.setEnabled(False)
        self.pushButton_killAllCurvePoints.setMaximumSize(QtCore.QSize(70, 16777215))
        self.pushButton_killAllCurvePoints.setObjectName("pushButton_killAllCurvePoints")
        self.horizontalLayout_curvepoints.addWidget(self.pushButton_killAllCurvePoints)
        self.verticalLayout.addLayout(self.horizontalLayout_curvepoints)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(6)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.line_2 = QtWidgets.QFrame(Form)
        self.line_2.setMinimumSize(QtCore.QSize(28, 0))
        self.line_2.setBaseSize(QtCore.QSize(50, 0))
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout.addWidget(self.line_2)
        self.verticalLayout_points_settings = QtWidgets.QVBoxLayout()
        self.verticalLayout_points_settings.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_points_settings.setSpacing(6)
        self.verticalLayout_points_settings.setObjectName("verticalLayout_points_settings")
        self.horizontalLayout.addLayout(self.verticalLayout_points_settings)
        self.verticalLayout.addLayout(self.horizontalLayout)
        spacerItem5 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem5)

        self.retranslateUi(Form)
        self.pushButton_kill.clicked.connect(Form.close)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.groupBox_friction.setTitle(_translate("Form", "Frictional parameters"))
        self.label_phiD.setToolTip(_translate("Form", "Basal friction angle [deg]"))
        self.label_phiB.setToolTip(_translate("Form", "Bulk friction angle [deg]"))
        self.label.setText(_translate("Form", "<sup>3</sup>"))
        self.label_2.setText(_translate("Form", "<sup>4</sup>"))
        self.groupBox_fluids.setToolTip(_translate("Form", "Check to activate fluids pore pressure parameters (Alt+F)"))
        self.groupBox_fluids.setTitle(_translate("Form", "&Fluids pore pressure"))
        self.label_rhosr.setToolTip(_translate("Form", "Volumetric mass density of saturated rock"))
        self.label_3.setText(_translate("Form", "<sup>5</sup>"))
        self.label_lamdaD.setToolTip(_translate("Form", "Basal fluids overpressure ratio"))
        self.label_lamdaB.setToolTip(_translate("Form", "Bulk fluids overpressure ratio"))
        self.label_4.setText(_translate("Form", "<sup>6</sup>"))
        self.label_rhof.setToolTip(_translate("Form", "Volumetric mass density of fluids"))
        self.label_5.setText(_translate("Form", "<sup>7</sup>"))
        self.label_6.setText(_translate("Form", "<sup>8</sup>"))
        self.pushButton_kill.setToolTip(_translate("Form", "Delete this curve (Ctrl+Del)"))
        self.pushButton_kill.setShortcut(_translate("Form", "Ctrl+Del"))
        self.checkBox_splittedCurves.setToolTip(_translate("Form", "Check to draw with separate settings normal and inverse faulting mechanisms (Alt+D)"))
        self.checkBox_splittedCurves.setText(_translate("Form", "&Distinguish mechanisms"))
        self.checkBox_reverseColormap.setToolTip(_translate("Form", "Check to reverse  (Alt+V)"))
        self.checkBox_reverseColormap.setText(_translate("Form", "Re&verse colormap"))
        self.pushButton_addCurvePoint.setToolTip(_translate("Form", "Add a new point on current curve (Ctrl+P)"))
        self.pushButton_addCurvePoint.setText(_translate("Form", "+"))
        self.pushButton_addCurvePoint.setShortcut(_translate("Form", "Ctrl+P"))
        self.label_CurvePoint.setText(_translate("Form", "<u>P</u>oints on this curve"))
        self.pushButton_killAllCurvePoints.setToolTip(_translate("Form", "Delete all points on current curve"))
        self.pushButton_killAllCurvePoints.setText(_translate("Form", "Clear all"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

